import { ISearchUserParams } from './interfaces/user/Search';
import "../typings/string.extension";
import { IResponseBase } from './interfaces/Response';
import { IRenameMissionParams, IDeleteMissionParams, IGetAliyunOSSDownloadURLParams } from './interfaces/APIParams';
import { IGetCloudJobsParams, ICreateCloudJobParams, IGetJobStatusParams, IRemoveJobsParams, IRestartJobsParams, ICreateMeshJobParams, IGetMeshJobsParams, ISearchJobsParams, IStartCloudJobParams, IAddCloudJobResourcesParams, IBulkCreateMeshJobParams } from './interfaces/service/Job';
import { IShareMissionParams, IRemoveMemberParams, IRecoverMissionParams, ISearchMissionListParams, IMissionInfoParams, IEmptyTrashMissionParams } from './interfaces/mission/Mission';
import { VerificationFlow, AccountType, ILogoutParams } from './interfaces/user/UserSignin';
import { IOAuthAuthorizeParams, IOAuthTokenParams } from './interfaces/oauth/OAuth';
import { IAddClipsParams } from './interfaces/mission/Mission';
export declare function signup(user: any): Promise<import("axios").AxiosResponse<any>>;
export declare function getCaptcha(): Promise<any>;
export declare function checkCaptcha(data: any): Promise<any>;
export declare function signin(user: any): Promise<import("axios").AxiosResponse<any>>;
/**
 * Logout API
 */
export declare function logout(params: ILogoutParams): Promise<import("axios").AxiosResponse<IResponseBase>>;
/**
 * OAuth authorize API
 */
export declare function oauthAuthorize(params: IOAuthAuthorizeParams): Promise<import("axios").AxiosResponse<any>>;
export declare function accessOAuthAuthrize(param: IOAuthAuthorizeParams): Promise<import("axios").AxiosResponse<any>>;
export declare function getOAuthToken(param: IOAuthTokenParams): Promise<any>;
export declare function refleshToken(refreshToken: any): Promise<import("axios").AxiosResponse<any>>;
export declare function checkUsername(username: any): Promise<import("axios").AxiosResponse<any>>;
export declare function checkAccount(user: any): Promise<import("axios").AxiosResponse<any>>;
/**
 * Get sms code from server
 *
 * @param {string} areaCode - area code of the phone requesting this code
 * @param {string} phone - phone number requesting this code
 * @param {VerificationFlow} - flow this verification is used for
 * @param {string} accessToken - accesstoken if needed
 */
export declare function getSmsCode(areaCode: string, phone: string, flow: VerificationFlow, accessToken?: string): Promise<import("axios").AxiosResponse<any>>;
export declare function updateUserData(user: any): Promise<import("axios").AxiosResponse<any>>;
export declare function verifySmsCode(data: any): Promise<import("axios").AxiosResponse<any>>;
export declare function checkUserInfo(params: any): Promise<import("axios").AxiosResponse<any>>;
export declare function forgetPasswordReset(params: any): Promise<import("axios").AxiosResponse<any>>;
export declare function resetPassword(params: any): Promise<import("axios").AxiosResponse<any>>;
/**
 * Get the email verification code
 *
 * @param {string} email - email requesting this code
 * @param {VerificationFlow} - flow this verification is used for
 * @param {string} accessToken - accesstoken if needed
 * @param {AccountType} accountType - only needed in `verifyOldAccount` flow, should be `phone` or `email`
 */
export declare function getEmailCode(email: string, flow: VerificationFlow, accessToken: string, accountType?: AccountType): Promise<import("axios").AxiosResponse<any>>;
export declare function verifyEmailCode(data: any): Promise<import("axios").AxiosResponse<any>>;
export declare function resetEmailPassword(params: any): Promise<import("axios").AxiosResponse<any>>;
export declare function getUploadToken(key: any): Promise<import("axios").AxiosResponse<any>>;
export declare function uploadToQiniu(url: any, data: any, options?: any): Promise<import("axios").AxiosResponse<any>>;
export declare function changeEmail(params: any): Promise<import("axios").AxiosResponse<any>>;
export declare function changePhone(params: any): Promise<import("axios").AxiosResponse<any>>;
/**
 * Send a `POST` request to rename a given mission
 *
 * @param params - params matching the API doc
 */
export declare function postRenameMission(params: IRenameMissionParams): Promise<any>;
/**
 * Send a `POST` request to delete a specific mission
 *
 * @param params - params matching the API doc
 */
export declare function postDeleteMission(params: IDeleteMissionParams): Promise<import("axios").AxiosResponse<any>>;
/**
 * Get download url for resources on Aliyun OSS
 */
export declare function getAliyunOSSDownloadUrl(params: IGetAliyunOSSDownloadURLParams): Promise<import("axios").AxiosResponse<any>>;
export declare function postRecoverMission(params: any): Promise<import("axios").AxiosResponse<any>>;
/**
 * Gets the product info from mesh server
 *
 * @param productId - id of product we are looking at
 * @param lang - language parameter we are including in headers to get proper localiztion messages
 */
export declare function getProduct(productId: string, lang: string): Promise<any>;
/**
 * Gets a list of mission for a specific user
 *
 * @param {number} userId - id of user owning missions
 * @param {string} accessToken - access token of the mission
 * @param {number} page - optional, the page of mission returned
 * @param {number} cnt - optional, the maximum number of mission returned
 * @param {string} missionName - optional, search missions by name
 * @param {boolean} deleted - optional, whether to return deleted missions or not
 */
export declare function getMissions(userId: any, accessToken: any, page: any, cnt: any, missionName: any, deleted?: boolean): Promise<any>;
/**
 * Return list of features of a mission for a specific user
 *
 * @param {number} userId - id of user owning missions
 * @param {number} missionId - id of the mission
 * @param {string} accessToken - access token of the mission
 */
export declare function getFeatures(userId: any, missionId: any, accessToken: any): Promise<any>;
export declare function getDeletedMissions(userId: any, accessToken: any, page: any): Promise<import("axios").AxiosResponse<any>>;
export declare function getMissionEvents({ userId, missionId, accessToken, page }: {
    userId: any;
    missionId: any;
    accessToken: any;
    page: any;
}): Promise<import("axios").AxiosResponse<any>>;
/**
 * @export getMissionDevices
 * @param {accessToken: String, missionId: String} params
 * @returns Api call
 */
export declare function getMissionDevices({ accessToken, missionId }: {
    accessToken: any;
    missionId: any;
}): Promise<any>;
export declare function getMissionTorrents({ accessToken, missionId }: {
    accessToken: any;
    missionId: any;
}): Promise<import("axios").AxiosResponse<any>>;
/**
 *
 * @export
 * @param {any} params
 * @param {String} params.accessToken - access token for mesh-server.
 * @param {String} params.bucket - name of the bucket in qiniu.
 * @param {String} params.key - will be id for that torrent files.
 * @returns {Object}
 * "data": {
 *          "uploadUrl": "http://upload.qiniu.com/",        // 上传 url
 *          "uploadToken": "GtMGhFn8tHX4Wsb8V0MbQN8JoCCRuWOPUxQSWCeb:WzLepNiD4GicZpvCuhecaROdo9E=:eyJzY29wZSI6Im1lc2gtYXZhdGFyOmFzZGtqbHp4aGNsa2pxd25lbGtqcW5renhjYXNkYXNkIiwiZGVhZGxpbmUiOjE0NzUwMzM2ODN9",
 *          "downloadUrl": "http://oe6xdldcb.bkt.clouddn.com/key"       // 下载 url
 *      }
 */
export declare function getCDNUploadToken(params: any): Promise<import("axios").AxiosResponse<any>>;
export declare function checkCDNfileExist(resourceUrl: any): Promise<import("axios").AxiosResponse<any>>;
export declare function postStartAjob(params: any): Promise<import("axios").AxiosResponse<any>>;
export declare function getJobStatus(params: any): Promise<import("axios").AxiosResponse<any>>;
/**
 * Create a service job with in a mesh mission
 *
 * @param {ICreateMeshJobParams} - parameters used to create a mesh service job
 */
export declare function createMeshJob(params: ICreateMeshJobParams): Promise<any>;
/**
 * Get all service jobs with in a mesh mission
 *
 * @param {IGetMeshJobsParams} - parameters used to create a mesh service job
 */
export declare function getMeshJobs(params: IGetMeshJobsParams): Promise<any>;
/**
 *
 *
 * @export
 * @param {any} params
 * @param {String} params.accessToken - access token for mesh-server.
 * @param {String} params.bucket - name of the bucket in qiniu.
 * @param {String} params.key -- will be id for that torrent files.
 * @returns
 * "data": {
 *          "downloadUrl": "http://oe6xdldcb.bkt.clouddn.com"
 *      }
 */
export declare function getCDNDownloadURL(params: any): Promise<import("axios").AxiosResponse<any>>;
export declare function uploadMissionTorrents(params: any): Promise<import("axios").AxiosResponse<any>>;
export declare function updateTorrentInformation(params: any): Promise<import("axios").AxiosResponse<any>>;
export declare function getSubscriptionList(accessToken: any): Promise<import("axios").AxiosResponse<any>>;
export declare function subscribe(userId: any, params: any): Promise<import("axios").AxiosResponse<any>>;
export declare function getUserSubscription(userId: any, accessToken: any): Promise<import("axios").AxiosResponse<any>>;
export declare function uploadKml(formData: any): Promise<any>;
/**
 * Gets captured position record for a mission
 *
 * @param {string} accessToken - access token for theuser
 * @param {bigint} missionId - id of mission we are looking at
 */
export declare function getCapturePositionRecordForMission(accessToken: any, missionId: any): Promise<any>;
/**
 * Getting OSS AccessToken
 *
 * @param {any} params - params to post to url in order to get oss access token
 */
export declare function getOSSAccessToken(params: any): Promise<import("axios").AxiosResponse<any>>;
/**
 * Add clips to database
 *
 * @param {IAddClipsParams} params
 */
export declare function addClips(params: IAddClipsParams): Promise<import("axios").AxiosResponse<any>>;
/**
 * Delete clips from database
 *
 * @param {any} params
 */
export declare function deleteClips(params: any): Promise<import("axios").AxiosResponse<any>>;
/**
 * Returns the geo information by referencing lat/lng from google/gaode map api
 *
 * Related doc:
 * https://developers.google.com/maps/documentation/geocoding/start?csw=1#ReverseGeocoding
 * https://lbs.amap.com/api/webservice/guide/api/georegeo
 *
 * @param lat - lattitude to reference the geo information
 * @param lng - longitude to reference the geo information
 * @param lang - language to be returned
 */
export declare function getGeocode(lat: number, lng: number, lang: string): Promise<any>;
/**
 * Service related
 */
export declare function getJobsStatus(params: IGetJobStatusParams): Promise<any>;
/**
 * Create an independent cloud job
 *
 * @param {ICreateCLoudJobParams} params - parameters to create an independent cloud job
 */
export declare function createCloudJob(params: ICreateCloudJobParams): Promise<any>;
/**
 * Create some independent cloud job
 * @param params {IBulkCreateMeshJobParams} params - parameters to create some independent cloud job
 */
export declare function blukCreateCloudJob(params: IBulkCreateMeshJobParams): Promise<any>;
/**
 * Get a list of cloud jobs
 */
export declare function getCloudJobs(params: IGetCloudJobsParams, useMock?: boolean): Promise<any>;
/**
 * Start a cloud job
 */
export declare function startCloudJob(params: IStartCloudJobParams): Promise<any>;
/**
 * Add resources to a cloud job
 */
export declare function addCloudJobResources(params: IAddCloudJobResourcesParams): Promise<any>;
/**
 * Remove a cloud job
 *
 * @param {IRemoveJobsParams} params - parameters to remove a cloud job
 */
export declare function cancelCloudJobs(params: IRemoveJobsParams): Promise<any>;
/**
 * Restart a list of cloud jobs
 *
 * @param {IRestartJobsParams} params - parameters to restart a list of cloud jobs
 */
export declare function restartCloudJobs(params: IRestartJobsParams): Promise<any>;
/**
 * Search jobs and return a list of job objects
 *
 * @param {ISearchJobsParams} params - parameters used to search jobs
 */
export declare function searchJobs(params: ISearchJobsParams): Promise<any>;
/**
 * Search a user and return a list of user objects
 *
 * @param {ISearchUserParams} params - parameters used to search a user
 */
export declare function searchUser(params: ISearchUserParams): Promise<any>;
/**
 * Recover a mission
 *
 * @param {IRecoverMissionParams} params - parameters used to recover a mission
 */
export declare function recoverMission(params: IRecoverMissionParams): Promise<any>;
/**
 * Delete missions
 *
 * @param {IEmptyTrashMissionParams} params
 */
export declare function emptyTrashMission(params: IEmptyTrashMissionParams): Promise<any>;
/**
 * Share a mission with a user
 *
 * @param {IShareMissionParams} params - parameters used to share a mission
 */
export declare function shareMission(params: IShareMissionParams): Promise<any>;
/**
 * Remove a member from a mission
 *
 * @param {IRemoveMemberParams} params - parameters used to remove a member from a mission
 */
export declare function removeMember(params: IRemoveMemberParams): Promise<any>;
/**
 * Search missions
 *
 * @param params - parameters used to search missions
 */
export declare function searchMissions(params: ISearchMissionListParams): Promise<import("axios").AxiosResponse<any>>;
/**
 * Get mission info
 * @param params  - parameters used to get mission
 */
export declare function missionInfo(params: IMissionInfoParams): Promise<any>;
