"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getOSSAccessToken = exports.getCapturePositionRecordForMission = exports.uploadKml = exports.getUserSubscription = exports.subscribe = exports.getSubscriptionList = exports.updateTorrentInformation = exports.uploadMissionTorrents = exports.getCDNDownloadURL = exports.getMeshJobs = exports.createMeshJob = exports.getJobStatus = exports.postStartAjob = exports.checkCDNfileExist = exports.getCDNUploadToken = exports.getMissionTorrents = exports.getMissionDevices = exports.getMissionEvents = exports.getDeletedMissions = exports.getFeatures = exports.getMissions = exports.getProduct = exports.postRecoverMission = exports.getAliyunOSSDownloadUrl = exports.postDeleteMission = exports.postRenameMission = exports.changePhone = exports.changeEmail = exports.uploadToQiniu = exports.getUploadToken = exports.resetEmailPassword = exports.verifyEmailCode = exports.getEmailCode = exports.resetPassword = exports.forgetPasswordReset = exports.checkUserInfo = exports.verifySmsCode = exports.updateUserData = exports.getSmsCode = exports.checkAccount = exports.checkUsername = exports.refleshToken = exports.getOAuthToken = exports.accessOAuthAuthrize = exports.oauthAuthorize = exports.logout = exports.signin = exports.checkCaptcha = exports.getCaptcha = exports.signup = void 0;
exports.missionInfo = exports.searchMissions = exports.removeMember = exports.shareMission = exports.emptyTrashMission = exports.recoverMission = exports.searchUser = exports.searchJobs = exports.restartCloudJobs = exports.cancelCloudJobs = exports.addCloudJobResources = exports.startCloudJob = exports.getCloudJobs = exports.blukCreateCloudJob = exports.createCloudJob = exports.getJobsStatus = exports.getGeocode = exports.deleteClips = exports.addClips = void 0;
/// <reference path="../typings/string.extension.d.ts" />
const jshashes_1 = require("jshashes");
const js_base64_1 = require("js-base64");
const http_1 = require("./http");
require("../typings/string.extension");
const Response_1 = require("./interfaces/Response");
const Job_1 = require("./interfaces/service/Job");
const MockServiceJob_1 = require("./MockData/MockServiceJob");
const Feature_1 = require("./interfaces/mission/Feature");
const md5 = (str) => new jshashes_1.MD5().hex(str);
function signup(user) {
    const url = 'signup';
    user = Object.assign(user, {
        password: md5(user.password)
    });
    return http_1.default.post(url, user);
}
exports.signup = signup;
function getCaptcha() {
    const url = 'captcha';
    return http_1.default.get(url);
}
exports.getCaptcha = getCaptcha;
function checkCaptcha(data) {
    const url = 'captcha';
    return http_1.default.post(url, data);
}
exports.checkCaptcha = checkCaptcha;
function signin(user) {
    const url = 'signin';
    user = Object.assign(user, {
        password: md5(user.password)
    });
    return http_1.default.post(url, user, {
        maxRedirects: 1,
    });
}
exports.signin = signin;
/**
 * Logout API
 */
function logout(params) {
    const url = "logout";
    return http_1.default.post(url, params);
}
exports.logout = logout;
/**
 * OAuth authorize API
 */
function oauthAuthorize(params) {
    const url = "oauth/authorize";
    return http_1.default.post(url, params);
}
exports.oauthAuthorize = oauthAuthorize;
function accessOAuthAuthrize(param) {
    const url = `oauth/authorize?clientId=${param.clientId}&redirectURL=${param.redirectURL}`;
    return http_1.default.get(url);
}
exports.accessOAuthAuthrize = accessOAuthAuthrize;
function getOAuthToken(param) {
    const url = 'oauth/token';
    return http_1.default.post(url, param);
}
exports.getOAuthToken = getOAuthToken;
function refleshToken(refreshToken) {
    const url = `auth/refresh?refreshToken=${refleshToken}`;
    return http_1.default.post(url);
}
exports.refleshToken = refleshToken;
function checkUsername(username) {
    const url = `checkUsername/${username}`;
    return http_1.default.get(url);
}
exports.checkUsername = checkUsername;
function checkAccount(user) {
    let url = `checkAccount/${user.account}?accountType=${user.accountType}`;
    if (user.accountType === 'phone') {
        url += `&areaCode=${encodeURIComponent(user.areaCode)}`;
    }
    return http_1.default.get(url);
}
exports.checkAccount = checkAccount;
/**
 * Get sms code from server
 *
 * @param {string} areaCode - area code of the phone requesting this code
 * @param {string} phone - phone number requesting this code
 * @param {VerificationFlow} - flow this verification is used for
 * @param {string} accessToken - accesstoken if needed
 */
function getSmsCode(areaCode, phone, flow, accessToken) {
    let url = `requestSmsCode?areaCode=${areaCode}&phone=${phone}&flow=${flow}`;
    if (flow === 'verifyOldAccount') {
        url += `&accessToken=${accessToken}`;
    }
    return http_1.default.get(url);
}
exports.getSmsCode = getSmsCode;
function updateUserData(user) {
    const url = `updateUser/${user.userId}`;
    return http_1.default.post(url, user);
}
exports.updateUserData = updateUserData;
function verifySmsCode(data) {
    const url = `verifySmsCode`;
    return http_1.default.post(url, data);
}
exports.verifySmsCode = verifySmsCode;
function checkUserInfo(params) {
    const url = 'checkUserInfo';
    return http_1.default.post(url, params);
}
exports.checkUserInfo = checkUserInfo;
function forgetPasswordReset(params) {
    const url = `forgetPassword/reset`;
    params = Object.assign(params, {
        password: md5(params.password)
    });
    return http_1.default.post(url, params);
}
exports.forgetPasswordReset = forgetPasswordReset;
function resetPassword(params) {
    const url = `resetPassword`;
    params = Object.assign(params, {
        newPassword: md5(params.newPassword),
        oldPassword: md5(params.oldPassword)
    });
    return http_1.default.post(url, params);
}
exports.resetPassword = resetPassword;
/**
 * Get the email verification code
 *
 * @param {string} email - email requesting this code
 * @param {VerificationFlow} - flow this verification is used for
 * @param {string} accessToken - accesstoken if needed
 * @param {AccountType} accountType - only needed in `verifyOldAccount` flow, should be `phone` or `email`
 */
function getEmailCode(email, flow, accessToken, accountType) {
    let url = `requestEmailCode?email=${email}&flow=${flow}`;
    if (flow === 'verifyOldAccount') {
        url += `&accessToken=${accessToken}&accountType=${accountType}`;
    }
    return http_1.default.get(url);
}
exports.getEmailCode = getEmailCode;
function verifyEmailCode(data) {
    const url = `verifyEmailCode`;
    return http_1.default.post(url, data);
}
exports.verifyEmailCode = verifyEmailCode;
function resetEmailPassword(params) {
    const url = `emailPassword`;
    params = Object.assign({}, params, {
        password: md5(params.password)
    });
    return http_1.default.post(url, params);
}
exports.resetEmailPassword = resetEmailPassword;
// Only use with login page avatar upload
function getUploadToken(key) {
    let data = {
        bucket: 'mesh-avatar',
        key: key,
        applyTime: Date.now()
    };
    data = JSON.stringify(data);
    const param = js_base64_1.Base64.encodeURI(data);
    const salt = 'iF0DcUu1xNj8IjTBIw02scEaZjCW1n0oYuRpWk9G';
    const sign = new jshashes_1.SHA1().b64_hmac(salt, param);
    const url = `v2/cdn/uploadToken`;
    return http_1.default.post(url, {
        sign: sign,
        param: param
    });
}
exports.getUploadToken = getUploadToken;
// Depricated
function uploadToQiniu(url, data, options) {
    return http_1.default.post(url, data, options);
}
exports.uploadToQiniu = uploadToQiniu;
function changeEmail(params) {
    const url = `changeEmail`;
    return http_1.default.post(url, params);
}
exports.changeEmail = changeEmail;
function changePhone(params) {
    const url = `changePhone`;
    return http_1.default.post(url, params);
}
exports.changePhone = changePhone;
/**
 * Send a `POST` request to rename a given mission
 *
 * @param params - params matching the API doc
 */
function postRenameMission(params) {
    const url = 'mission/rename';
    return http_1.default.post(url, params);
}
exports.postRenameMission = postRenameMission;
/**
 * Send a `POST` request to delete a specific mission
 *
 * @param params - params matching the API doc
 */
function postDeleteMission(params) {
    const url = 'mission/delete';
    return http_1.default.post(url, params);
}
exports.postDeleteMission = postDeleteMission;
/**
 * Get download url for resources on Aliyun OSS
 */
function getAliyunOSSDownloadUrl(params) {
    const url = `oss/downloadUrl?url=${params.url}&bucket=${params.bucket}&objectName=${params.objectName}&accessToken=${params.accessToken}`;
    return http_1.default.get(url);
}
exports.getAliyunOSSDownloadUrl = getAliyunOSSDownloadUrl;
function postRecoverMission(params) {
    const url = 'mission/recover';
    return http_1.default.post(url, params);
}
exports.postRecoverMission = postRecoverMission;
/**
 * Gets the product info from mesh server
 *
 * @param productId - id of product we are looking at
 * @param lang - language parameter we are including in headers to get proper localiztion messages
 */
function getProduct(productId, lang) {
    const url = `product?productId=${productId}`;
    return http_1.default.get(url, {
        headers: {
            'Accept-Language': lang,
        }
    });
}
exports.getProduct = getProduct;
/**
 * Gets a list of mission for a specific user
 *
 * @param {number} userId - id of user owning missions
 * @param {string} accessToken - access token of the mission
 * @param {number} page - optional, the page of mission returned
 * @param {number} cnt - optional, the maximum number of mission returned
 * @param {string} missionName - optional, search missions by name
 * @param {boolean} deleted - optional, whether to return deleted missions or not
 */
function getMissions(userId, accessToken, page, cnt, missionName, deleted = false) {
    const GET_MISSION_BASE_ENDPOINT = "users/{0}/missions?accessToken={1}&order=desc";
    const COUNT_QUERY = "&count={0}";
    const PAGE_QUERY = "&page={0}";
    const DELETED_QUERY = "&trash={0}";
    const NAME_QUERY = "&missionName={0}";
    let url = GET_MISSION_BASE_ENDPOINT.format(userId, accessToken);
    if (page) {
        url += PAGE_QUERY.format(page);
    }
    if (cnt) {
        url += COUNT_QUERY.format(cnt);
    }
    if (deleted) {
        url += DELETED_QUERY.format(deleted.toString());
    }
    if (missionName) {
        url += NAME_QUERY.format(missionName);
    }
    return http_1.default.get(url);
}
exports.getMissions = getMissions;
/**
 * Return list of features of a mission for a specific user
 *
 * @param {number} userId - id of user owning missions
 * @param {number} missionId - id of the mission
 * @param {string} accessToken - access token of the mission
 */
function getFeatures(userId, missionId, accessToken) {
    const GET_FEATURES_BASE_ENDPOINT = "users/{0}/missions/{1}/features?accessToken={2}";
    const url = GET_FEATURES_BASE_ENDPOINT.format(userId, missionId, accessToken);
    return http_1.default.get(url);
}
exports.getFeatures = getFeatures;
function getDeletedMissions(userId, accessToken, page) {
    const url = `users/${userId}/missions?accessToken=${accessToken}&count=15&order=incr&page=${page}&trash=true`;
    return http_1.default.get(url);
}
exports.getDeletedMissions = getDeletedMissions;
function getMissionEvents({ userId, missionId, accessToken, page }) {
    // const url = `users/${userId}/missions/${missionId}/events?accessToken=${accessToken}&count=20&page=${page}&filter=image,video`
    const url = `users/${userId}/missions/${missionId}/events?accessToken=${accessToken}`;
    return http_1.default.get(url);
}
exports.getMissionEvents = getMissionEvents;
/**
 * @export getMissionDevices
 * @param {accessToken: String, missionId: String} params
 * @returns Api call
 */
function getMissionDevices({ accessToken, missionId }) {
    const url = `mission/devices?accessToken=${accessToken}&missionId=${missionId}`;
    return http_1.default.get(url);
}
exports.getMissionDevices = getMissionDevices;
function getMissionTorrents({ accessToken, missionId }) {
    const url = `torrents?accessToken=${accessToken}&missionId=${missionId}`;
    return http_1.default.get(url);
}
exports.getMissionTorrents = getMissionTorrents;
/**
 *
 * @export
 * @param {any} params
 * @param {String} params.accessToken - access token for mesh-server.
 * @param {String} params.bucket - name of the bucket in qiniu.
 * @param {String} params.key - will be id for that torrent files.
 * @returns {Object}
 * "data": {
 *          "uploadUrl": "http://upload.qiniu.com/",        // 上传 url
 *          "uploadToken": "GtMGhFn8tHX4Wsb8V0MbQN8JoCCRuWOPUxQSWCeb:WzLepNiD4GicZpvCuhecaROdo9E=:eyJzY29wZSI6Im1lc2gtYXZhdGFyOmFzZGtqbHp4aGNsa2pxd25lbGtqcW5renhjYXNkYXNkIiwiZGVhZGxpbmUiOjE0NzUwMzM2ODN9",
 *          "downloadUrl": "http://oe6xdldcb.bkt.clouddn.com/key"       // 下载 url
 *      }
 */
function getCDNUploadToken(params) {
    const url = `cdn/uploadToken?accessToken=${params.accessToken}&bucket=${params.bucket}&key=${params.key}`;
    return http_1.default.get(url);
}
exports.getCDNUploadToken = getCDNUploadToken;
function checkCDNfileExist(resourceUrl) {
    const url = `${resourceUrl}?stat`;
    return http_1.default.get(url);
}
exports.checkCDNfileExist = checkCDNfileExist;
// TODO: rename this ORZ
async function postStartAjob(params) {
    const url = `service/job`;
    return await http_1.default.post(url, params);
}
exports.postStartAjob = postStartAjob;
async function getJobStatus(params) {
    const url = `service/job/status?accessToken=${params.accessToken}&missionId=${params.missionId}&featureHash=${params.featureHash}&serviceId=${params.serviceId}&eventType=${params.eventType}`;
    return await http_1.default.get(url);
}
exports.getJobStatus = getJobStatus;
/**
 * Create a service job with in a mesh mission
 *
 * @param {ICreateMeshJobParams} - parameters used to create a mesh service job
 */
function createMeshJob(params) {
    const url = "/service/meshJob";
    return http_1.default.post(url, params);
}
exports.createMeshJob = createMeshJob;
/**
 * Get all service jobs with in a mesh mission
 *
 * @param {IGetMeshJobsParams} - parameters used to create a mesh service job
 */
function getMeshJobs(params) {
    const { accessToken, missionId } = params;
    const BASE_URL = "service/meshJobs?accessToken={0}&missionId={1}";
    const url = BASE_URL.format(accessToken, missionId);
    return http_1.default.get(url);
}
exports.getMeshJobs = getMeshJobs;
/**
 *
 *
 * @export
 * @param {any} params
 * @param {String} params.accessToken - access token for mesh-server.
 * @param {String} params.bucket - name of the bucket in qiniu.
 * @param {String} params.key -- will be id for that torrent files.
 * @returns
 * "data": {
 *          "downloadUrl": "http://oe6xdldcb.bkt.clouddn.com"
 *      }
 */
function getCDNDownloadURL(params) {
    const url = `cdn/downloadURL?accessToken=${params.accessToken}&bucket=${params.bucket}&key=${params.key}`;
    return http_1.default.get(url);
}
exports.getCDNDownloadURL = getCDNDownloadURL;
function uploadMissionTorrents(params) {
    const url = `torrents`;
    return http_1.default.post(url, params);
}
exports.uploadMissionTorrents = uploadMissionTorrents;
function updateTorrentInformation(params) {
    const url = `torrents/update`;
    return http_1.default.post(url, params);
}
exports.updateTorrentInformation = updateTorrentInformation;
function getSubscriptionList(accessToken) {
    const url = `subscriptions?accessToken=${accessToken}`;
    return http_1.default.get(url);
}
exports.getSubscriptionList = getSubscriptionList;
function subscribe(userId, params) {
    const url = `users/${userId}/subscription`;
    return http_1.default.post(url, params);
}
exports.subscribe = subscribe;
function getUserSubscription(userId, accessToken) {
    const url = `users/${userId}/subscription?accessToken=${accessToken}`;
    return http_1.default.get(url);
}
exports.getUserSubscription = getUserSubscription;
function uploadKml(formData) {
    const url = `mission/config`;
    return http_1.default.post(url, formData);
}
exports.uploadKml = uploadKml;
/**
 * Gets captured position record for a mission
 *
 * @param {string} accessToken - access token for theuser
 * @param {bigint} missionId - id of mission we are looking at
 */
async function getCapturePositionRecordForMission(accessToken, missionId) {
    const BASE_URL = "mission/capture/position?accessToken={0}&missionId={1}";
    const url = BASE_URL.format(accessToken, missionId);
    return await http_1.default.get(url);
}
exports.getCapturePositionRecordForMission = getCapturePositionRecordForMission;
/**
 * Getting OSS AccessToken
 *
 * @param {any} params - params to post to url in order to get oss access token
 */
async function getOSSAccessToken(params) {
    const url = "/api/oss/ststoken";
    return await http_1.default.post(url, params);
}
exports.getOSSAccessToken = getOSSAccessToken;
/**
 * Add clips to database
 *
 * @param {IAddClipsParams} params
 */
async function addClips(params) {
    const url = "/mission/clips/add";
    return await http_1.default.post(url, params);
}
exports.addClips = addClips;
/**
 * Delete clips from database
 *
 * @param {any} params
 */
async function deleteClips(params) {
    const url = "/mission/clips/delete";
    return await http_1.default.post(url, params);
}
exports.deleteClips = deleteClips;
/**
 * Returns the geo information by referencing lat/lng from google/gaode map api
 *
 * Related doc:
 * https://developers.google.com/maps/documentation/geocoding/start?csw=1#ReverseGeocoding
 * https://lbs.amap.com/api/webservice/guide/api/georegeo
 *
 * @param lat - lattitude to reference the geo information
 * @param lng - longitude to reference the geo information
 * @param lang - language to be returned
 */
async function getGeocode(lat, lng, lang) {
    // Define some necessary constants
    const GAODE_DEV_KEY = "f7c545d3463b78938453242852c9980c";
    const GAODE_STATUS_OK = 200;
    const GOOGLE_STATUS_OK = "OK";
    const googleUrl = `http://maps.googleapis.com/maps/api/geocode/json?latlng=${lat},${lng}&sensor=true&language=${lang}`;
    const gaodeUrl = `https://restapi.amap.com/v3/geocode/regeo?key=${GAODE_DEV_KEY}&location=${lng},${lat}`;
    let response;
    if (lang === "zh-CN" || lang === "zh-TW") {
        response = await http_1.default.get(gaodeUrl);
        if (response.status === GAODE_STATUS_OK) {
            return response.regeocode && response.regeocode.addressComponent ? formatAddress(response.regeocode.addressComponent, lang) : null;
        }
    }
    else {
        response = await http_1.default.get(googleUrl);
        if (response.status === GOOGLE_STATUS_OK) {
            return response.results && response.results.length > 0 ? formatAddress(response.results[0], lang) : null;
        }
    }
}
exports.getGeocode = getGeocode;
/**
 * Return a formatted address from a given addressComponent returned by some Map API
 *
 * @param addressComponent - the returned addressComopnent we are looking at
 * @param lang - language to be returned
 */
function formatAddress(addressComponent, lang) {
    if (lang === "zh-CN" || lang === "zh-TW") {
        return `${addressComponent.country}${addressComponent.province}${addressComponent.city}${addressComponent.district}`;
    }
    else {
        return addressComponent.formatted_address.split(",").splice(1).join(",");
    }
}
/**
 * Service related
 */
function getJobsStatus(params) {
    const url = "/service/getJobsStatus";
    return http_1.default.post(url, params);
}
exports.getJobsStatus = getJobsStatus;
/**
 * Create an independent cloud job
 *
 * @param {ICreateCLoudJobParams} params - parameters to create an independent cloud job
 */
function createCloudJob(params) {
    const url = "/service/cloudJob";
    return http_1.default.post(url, params);
}
exports.createCloudJob = createCloudJob;
/**
 * Create some independent cloud job
 * @param params {IBulkCreateMeshJobParams} params - parameters to create some independent cloud job
 */
function blukCreateCloudJob(params) {
    const url = "/service/meshJobs";
    return http_1.default.post(url, params);
}
exports.blukCreateCloudJob = blukCreateCloudJob;
/**
 * Get a list of cloud jobs
 */
function getCloudJobs(params, useMock) {
    const { accessToken, page, count, order } = params;
    if (!useMock) {
        const BASE_URL = "/service/cloudJobs?accessToken={0}&page={1}&count={2}&order={3}";
        const url = BASE_URL.format(accessToken, page, count, order ? order : 'desc');
        return http_1.default.get(url);
    }
    else {
        const successJob = MockServiceJob_1.default.mockJob(null, Job_1.CloudServiceStatus.SUCCESS);
        const uploadingJob = MockServiceJob_1.default.mockJob(null, Job_1.CloudServiceStatus.UPLOADING);
        const pendingJob = MockServiceJob_1.default.mockJob(null, Job_1.CloudServiceStatus.PENDING);
        const failedJob = MockServiceJob_1.default.mockJob(null, Job_1.CloudServiceStatus.FAILED);
        const altizureJob = MockServiceJob_1.default.mockJob(Feature_1.ServiceIds.MESH_ALTIZURE, Job_1.CloudServiceStatus.PENDING);
        const panoramaJob = MockServiceJob_1.default.mockJob(Feature_1.ServiceIds.MESH_PANORAMA, Job_1.CloudServiceStatus.PENDING);
        const result = [successJob, pendingJob, uploadingJob, failedJob, altizureJob, panoramaJob];
        return new Promise((resolve, reject) => {
            resolve({
                code: Response_1.ResponseCode.SUCCESS,
                message: "",
                data: {
                    more: false,
                    jobs: result,
                },
            });
        });
    }
}
exports.getCloudJobs = getCloudJobs;
/**
 * Start a cloud job
 */
function startCloudJob(params) {
    const url = "/service/startJob";
    return http_1.default.post(url, params);
}
exports.startCloudJob = startCloudJob;
/**
 * Add resources to a cloud job
 */
function addCloudJobResources(params) {
    const url = "/service/jobResources";
    return http_1.default.post(url, params);
}
exports.addCloudJobResources = addCloudJobResources;
/**
 * Remove a cloud job
 *
 * @param {IRemoveJobsParams} params - parameters to remove a cloud job
 */
function cancelCloudJobs(params) {
    const url = "/service/removeJobs";
    /**
     * Restart a cloud job
     *
     * @param {IRemoveJobsParams} params - parameters to restart a cloud job
     */
    return http_1.default.post(url, params);
}
exports.cancelCloudJobs = cancelCloudJobs;
/**
 * Restart a list of cloud jobs
 *
 * @param {IRestartJobsParams} params - parameters to restart a list of cloud jobs
 */
function restartCloudJobs(params) {
    const url = "/service/restartJobs";
    return http_1.default.post(url, params);
}
exports.restartCloudJobs = restartCloudJobs;
/**
 * Search jobs and return a list of job objects
 *
 * @param {ISearchJobsParams} params - parameters used to search jobs
 */
function searchJobs(params) {
    const url = "/service/searchJobs";
    return http_1.default.post(url, params);
}
exports.searchJobs = searchJobs;
/**
 * Search a user and return a list of user objects
 *
 * @param {ISearchUserParams} params - parameters used to search a user
 */
function searchUser(params) {
    const url = "/user/search";
    return http_1.default.post(url, params);
}
exports.searchUser = searchUser;
/**
 * Recover a mission
 *
 * @param {IRecoverMissionParams} params - parameters used to recover a mission
 */
function recoverMission(params) {
    const url = "/mission/recover";
    return http_1.default.post(url, params);
}
exports.recoverMission = recoverMission;
/**
 * Delete missions
 *
 * @param {IEmptyTrashMissionParams} params
 */
function emptyTrashMission(params) {
    const url = '/mission/emptytrash';
    return http_1.default.post(url, params);
}
exports.emptyTrashMission = emptyTrashMission;
/**
 * Share a mission with a user
 *
 * @param {IShareMissionParams} params - parameters used to share a mission
 */
function shareMission(params) {
    const url = "/mission/share";
    return http_1.default.post(url, params);
}
exports.shareMission = shareMission;
/**
 * Remove a member from a mission
 *
 * @param {IRemoveMemberParams} params - parameters used to remove a member from a mission
 */
function removeMember(params) {
    const url = "/mission/removeMember";
    return http_1.default.post(url, params);
}
exports.removeMember = removeMember;
/**
 * Search missions
 *
 * @param params - parameters used to search missions
 */
function searchMissions(params) {
    const url = 'mission/search';
    return http_1.default.post(url, params);
}
exports.searchMissions = searchMissions;
/**
 * Get mission info
 * @param params  - parameters used to get mission
 */
async function missionInfo(params) {
    const BASE_URL = "mission/info?accessToken={0}&missionId={1}";
    const url = BASE_URL.format(params.accessToken, params.missionId);
    return http_1.default.get(url);
}
exports.missionInfo = missionInfo;
