import { IUser } from "../user/User";
import { IDevice } from "../user/Device";
import { IResponseBase } from "../Response";
import { ILocation } from "../common/Location";
import { IServiceList } from '../service/Service';
declare enum ServiceIds {
    MESH_PANORAMA = 1,
    MESH_ODM = 2,
    DUMMY = 3,
    MESH_ALTIZURE,
    MESH_HAWKEYE_REPORT
}
declare enum ClipSource {
    MOBILE = 1,
    DESKTOP = 2,
    SERVICE = 3
}
interface IFeatureListItem {
    /**
     * The feature hash
     */
    featureHash: string;
    /**
     * Name of the feature
     */
    featureName: string;
    /**
     * Custom name of feature
     */
    customFeatureName: string;
    /**
     * Percentage of the feature's execution process
     */
    percentage: number;
    /**
     * Timestamp of feature creation
     */
    createdAt: number;
    /**
     * Timestamp of feature stopped time
     */
    stoppedAt: number;
    /**
     * Counts of photos generated in this feature
     */
    photoCnt: number;
    /**
     * Counts of videos generated in this feature
     */
    videoCnt: number;
    /**
     * Pilot of thisfeature
     */
    pilot: IUser;
    /**
     * Devices included inside this feature
     */
    devices: IDevice[];
    /**
     * Mission id of this feature
     */
    missionId: number;
    /**
     * Flight route executed in this feature
     */
    flightRoute: ILocation[];
    /**
     * Clip metadata for this feature
     */
    clipMetadata: IClipMetadata[];
    /**
     * Service id related to this feature, indicating which service could be used by this feature
     */
    serviceId?: ServiceIds;
    /**
     * Whether this feature was already used to successfully launch and complete a job
     */
    used?: boolean;
    /**
     * Whether this feature is in the process of a service job
     */
    processing?: boolean;
}
interface IClipMetadata {
    /**
     * Event id of the clip
     */
    eventId?: number;
    /**
     * Event type of the clip
     *
     * TODO: use enum
     */
    eventType?: number;
    /**
     * Feature hash of the clip
     */
    featureHash?: string;
    /**
     * Id of user adding clips
     */
    userId?: number;
    /**
     * GPS information
     */
    gps?: ILocation;
    /**
     * Whether this clip represents a service result or not
     */
    isServiceResult?: boolean;
    /**
     * Result of the clip (whether its the preview image or service result)
     */
    result?: string;
    /**
     * File metadata for the clip
     */
    file: IFile;
    /**
     * Started at timestamp
     */
    startedAt: number;
    /**
     * When this clip event stops
     */
    stoppedAt?: number;
    /**
     * Whether resource of this clip has been uploaded to our CDN or not
     */
    uploaded?: boolean;
    /**
     * Whehter resource of this clip exist locally or not
     */
    existLocally?: boolean;
    /**
     * Local path for the file, if existed
     */
    localPath?: string;
    /**
     * Download url from cloud, if any
     */
    downloadUrl?: string;
    /**
     * Id of device this clip is sent to
     */
    toDeviceId?: string;
    /**
     * Source of this clip
     */
    source?: ClipSource;
    /**
     * checkpoint for this file when upload a lot of that
     */
    checkpoint?: any;
    /**
     * uploaded size for this clips meta file
     */
    uploadedSize?: number;
}
interface IFile {
    id?: string;
    name: string;
    size: number;
    mediaType: number;
    /**
     * Path of the file
     */
    path?: string;
    /**
     * Timestamp we log this file information on server
     */
    timeCreated: string;
    /**
     * Timestamp of file creation on disk
     */
    birthtime?: number;
}
interface IFeatureList {
    [key: string]: IFeatureListItem;
}
interface IFeatureListtResponse extends IResponseBase {
    data: {
        features: IFeatureList;
        services?: IServiceList;
    };
}
export { IClipMetadata, IFeatureList, IFeatureListItem, IFeatureListtResponse, IFile, ServiceIds, ClipSource, };
