/**
 * Base interface for user object
 */
interface IUser {
    /**
     * Id of the user
     */
    userId?: number;
    /**
     * User's username
     */
    username?: string;
    /**
     * User's area code of his phone
     */
    areaCode?: string;
    /**
     * User's phone
     */
    phone?: string;
    /**
     * User's email
     */
    email?: string;
    /**
     * User's avatar
     */
    avatar?: string;
    /**
     * User's audio recorded to identify himself
     */
    audio?: string;
    /**
     * Account has been binded with phone or not
     */
    completed?: boolean;
    /**
     * Auth properties for the user
     */
    auth?: IUserAuth;
}
/**
 * Auth interface for a user
 */
interface IUserAuth {
    /**
     * Access token returned for user auth
     */
    accessToken: string;
    /**
     * Refresh token returned
     */
    refreshToken: string;
    /**
     * Expire timestamp
     */
    expiredAt: number;
    /**
     * Refresh token expire timestamp
     */
    refreshTokenExpiredAt: number;
}
/**
 * Privilege interface for user
 */
interface IPrivilege {
    /**
     * Account level in our pricing strategy
     */
    accountLevel: string;
    /**
     * Indicates how many times a user could create missions
     */
    missionTimes: number;
    /**
     * Maximum duration a mission could be executed
     */
    missionDuration: number;
    /**
     * Storage space in MB
     */
    storage: number;
    /**
     * Storage used in MB
     */
    usedStorage: number;
    /**
     * Num of basic genius
     */
    basicGenius: number;
    /**
     * Num of paid genius
     */
    paidGenius: number;
    /**
     * Num of trial genius
     */
    trialGenius: number;
    /**
     * Indicates how many times a user could create trial missions
     */
    trialMissionTimes: number;
    /**
     * Num of subscribed genius
     */
    subscriptionGenius: number;
    /**
     * gift cards this user owns
     */
    giftCards: IGiftCard[];
}
/**
 * Gift card interface
 */
interface IGiftCard {
    /**
     * Product ID matching app store product
     */
    productIdentifier: string;
    /**
     * Product Name
     */
    name: string;
    /**
     * Product description
     */
    description: string;
    /**
     * Product Price
     */
    price: number;
    /**
     * Num of genius this gift card contains
     */
    genius: number;
    /**
     * Valid duration (interval) this gift card could apply
     */
    interval: string;
    /**
     * Expiration timestamp
     */
    expiredAt: number;
}
export { IUserAuth, IUser, IPrivilege, IGiftCard, };
