"use strict";
/**
 * setup webview javascript bridge
 * bridge 通过 iframe 发送一个请求后，客户端通过调用 callback 传入生成的 bridge 对象
 * 最后 return 一个 promise 是用来兼容开发时没有 bridge 存在的情况，直接 resolve
 *
 *
 * https://github.com/marcuswestin/WebViewJavascriptBridge
 * @param {*} callback
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupWebViewJavascriptBridge = void 0;
function setupWebViewJavascriptBridge(callback) {
    if (window.WebViewJavascriptBridge) {
        return callback(window.WebViewJavascriptBridge);
    }
    else {
        document.addEventListener('WebViewJavascriptBridgeReady', function () {
            setupWebViewJavascriptBridge(callback);
        }, false);
    }
    if (window.WVJBCallbacks) {
        return window.WVJBCallbacks.push(callback);
    }
    window.WVJBCallbacks = [callback];
    var WVJBIframe = document.createElement('iframe');
    WVJBIframe.style.display = 'none';
    WVJBIframe.src = `${process.env.API_ROOT.indexOf("test") === -1 ? "https" : "http"}://__bridge_loaded__`;
    document.documentElement.appendChild(WVJBIframe);
    setTimeout(function () {
        document.documentElement.removeChild(WVJBIframe);
    }, 0);
    return Promise.resolve();
}
exports.setupWebViewJavascriptBridge = setupWebViewJavascriptBridge;
