import axios from 'axios'

const http = axios.create({
	baseURL: process.env.API_ROOT || "/api",
})

// response interceptors
http.interceptors.response.use(response =>
{
	// when http status code is 200 do something with response data
	console.log('response=', response)
	Object.assign(response.data, { config: response.config, status: response.status })
	return Promise.resolve(response.data)
}, error =>
{
	console.log('error.response=', error.response)
	if (error.response)
	{
		switch (error.response.status)
		{
			/**
			 * use 332 instead of 302, because 302 received but brower does not redirect
			 * see issues https://github.com/axios/axios/issues/396
			 * when brower need to redirect other website, can use http status code 332
			 */
			case 332:
				window.location.href = decodeURIComponent(error.response.headers.location)
				break
			case 500:
			default:
				console.error('response error:', error.response)
		}
	}
	else
	{
		// Network Error or Timeout reject error
		return Promise.reject(error)
	}
})

/**
 * response.data.code
 * 2 Invalide username
 * 3 Account not exists
 * 4 Invalide password
 * 5 Invalid access token
 * 6 Invalid parameters
 * 7 Account exists
 * 9 Data can not be validated
 * 10 Arrearage account
 * 11 user can not access mission
 * 12 device count is over limit
 * 13 request captcha too frequently. 5 times per day
 * 14 request error. Server request the third service error
 *
 * @param {*} response
 */
function handleStatusCode(response)
{
	const code = response.data.code
	Object.assign(response.data, { config: response.config, status: response.status })
	switch (code)
	{
		case undefined:
		case 1:
			return Promise.resolve(response.data)
		default:
			return Promise.reject(response)
	}
}

export default http
