import { ISearchUserParams } from './interfaces/user/Search';
/// <reference path="../typings/string.extension.d.ts" />

import { MD5, SHA1 } from 'jshashes'
import { Base64 } from 'js-base64'
import http from './http'
import "../typings/string.extension";
import { IMissionListResponse, IMissionInfoResponse } from './interfaces/mission/MissionList';
import { IProductResponse } from './interfaces/product/IProduct';
import { IFeatureListtResponse } from './interfaces/mission/Feature';
import { IMissionDeviceResponse } from './interfaces/mission/MissionDevice';
import { IResponseBase, ResponseCode } from './interfaces/Response';
import { IRenameMissionParams, IDeleteMissionParams, IGetAliyunOSSDownloadURLParams } from './interfaces/APIParams';
import { IGetCloudJobsParams, IGetCloudJobsResponse, CloudServiceStatus, ICreateCloudJobParams, ICreateCloudJobResponse, IGetJobStatusParams, IGetJobStatusResponse, IRemoveJobsParams, IRemoveJobsResponse, IRestartJobsParams, ICreateMeshJobParams, IGetMeshJobsParams, ISearchJobsParams, IStartCloudJobParams, IAddCloudJobResourcesParams, IBulkCreateMeshJobParams, IBulkCreateMeshJobResponse } from './interfaces/service/Job';
import MockServiceJob from './MockData/MockServiceJob';
import { ServiceIds } from './interfaces/mission/Feature';
import { IShareMissionParams, IRemoveMemberParams, IRecoverMissionParams, ISearchMissionListParams, IMissionInfoParams, IEmptyTrashMissionParams } from './interfaces/mission/Mission';
import { VerificationFlow, AccountType, ILogoutParams, ISigninResponse } from './interfaces/user/UserSignin';
import { IOAuthAuthorizeParams, IOAuthTokenParams } from './interfaces/oauth/OAuth';
import { IAddClipsParams } from './interfaces/mission/Mission';

const md5 = (str) => new MD5().hex(str);

export function signup(user)
{
	const url = 'signup'
	user = Object.assign(user, {
		password: md5(user.password)
	})
	return http.post(url, user)
}

export function getCaptcha(): Promise<any>
{
	const url = 'captcha'
	return http.get(url)
}

export function checkCaptcha(data): Promise<any>
{
	const url = 'captcha'
	return http.post<IResponseBase>(url, data)
}

export function signin(user)
{
	const url = 'signin'
	user = Object.assign(user, {
		password: md5(user.password)
	})
	return http.post(url, user, {
		maxRedirects: 1,
	})
}

/**
 * Logout API
 */
export function logout(params: ILogoutParams)
{
	const url = "logout";

	return http.post<IResponseBase>(url, params);
}

/**
 * OAuth authorize API
 */
export function oauthAuthorize(params: IOAuthAuthorizeParams)
{
	const url = "oauth/authorize";

	return http.post(url, params);
}

export function accessOAuthAuthrize(param: IOAuthAuthorizeParams)
{
	const url = `oauth/authorize?clientId=${param.clientId}&redirectURL=${param.redirectURL}`

	return http.get(url)
}

export function getOAuthToken(param: IOAuthTokenParams): Promise<any>
{
	const url = 'oauth/token'

	return http.post<ISigninResponse>(url, param)
}

export function refleshToken(refreshToken)
{
	const url = `auth/refresh?refreshToken=${refleshToken}`
	return http.post(url)
}

export function checkUsername(username)
{
	const url = `checkUsername/${username}`
	return http.get(url)
}

export function checkAccount(user)
{
	let url = `checkAccount/${user.account}?accountType=${user.accountType}`
	if (user.accountType === 'phone')
	{
		url += `&areaCode=${encodeURIComponent(user.areaCode)}`
	}
	return http.get(url)
}

/**
 * Get sms code from server
 *
 * @param {string} areaCode - area code of the phone requesting this code
 * @param {string} phone - phone number requesting this code
 * @param {VerificationFlow} - flow this verification is used for
 * @param {string} accessToken - accesstoken if needed
 */
export function getSmsCode(areaCode: string, phone: string, flow: VerificationFlow, accessToken?: string)
{
	let url = `requestSmsCode?areaCode=${areaCode}&phone=${phone}&flow=${flow}`
	if (flow === 'verifyOldAccount')
	{
		url += `&accessToken=${accessToken}`
	}
	return http.get(url)
}

export function updateUserData(user)
{
	const url = `updateUser/${user.userId}`
	return http.post(url, user)
}

export function verifySmsCode(data)
{
	const url = `verifySmsCode`
	return http.post(url, data)
}

export function checkUserInfo(params)
{
	const url = 'checkUserInfo'
	return http.post(url, params)
}

export function forgetPasswordReset(params)
{
	const url = `forgetPassword/reset`
	params = Object.assign(params, {
		password: md5(params.password)
	})
	return http.post(url, params)
}

export function resetPassword(params)
{
	const url = `resetPassword`
	params = Object.assign(params, {
		newPassword: md5(params.newPassword),
		oldPassword: md5(params.oldPassword)
	})
	return http.post(url, params)
}

/**
 * Get the email verification code
 *
 * @param {string} email - email requesting this code
 * @param {VerificationFlow} - flow this verification is used for
 * @param {string} accessToken - accesstoken if needed
 * @param {AccountType} accountType - only needed in `verifyOldAccount` flow, should be `phone` or `email`
 */
export function getEmailCode(email: string, flow: VerificationFlow, accessToken: string, accountType?: AccountType)
{
	let url = `requestEmailCode?email=${email}&flow=${flow}`
	if (flow === 'verifyOldAccount')
	{
		url += `&accessToken=${accessToken}&accountType=${accountType}`
	}
	return http.get(url)
}

export function verifyEmailCode(data)
{
	const url = `verifyEmailCode`
	return http.post(url, data)
}

export function resetEmailPassword(params)
{
	const url = `emailPassword`
	params = Object.assign({}, params, {
		password: md5(params.password)
	})
	return http.post(url, params)
}
// Only use with login page avatar upload
export function getUploadToken(key)
{
	let data: any = {
		bucket: 'mesh-avatar',
		key: key,
		applyTime: Date.now()
	}
	data = JSON.stringify(data)
	const param = Base64.encodeURI(data)
	const salt = 'iF0DcUu1xNj8IjTBIw02scEaZjCW1n0oYuRpWk9G'
	const sign = new SHA1().b64_hmac(salt, param)
	const url = `v2/cdn/uploadToken`
	return http.post(url, {
		sign: sign,
		param: param
	})
}

// Depricated
export function uploadToQiniu(url, data, options?: any)
{
	return http.post(url, data, options)
}

export function changeEmail(params)
{
	const url = `changeEmail`
	return http.post(url, params)
}

export function changePhone(params)
{
	const url = `changePhone`
	return http.post(url, params)
}

/**
 * Send a `POST` request to rename a given mission
 *
 * @param params - params matching the API doc
 */
export function postRenameMission(params: IRenameMissionParams): Promise<any>
{
	const url = 'mission/rename'
	return http.post(url, params)
}

/**
 * Send a `POST` request to delete a specific mission
 *
 * @param params - params matching the API doc
 */
export function postDeleteMission(params: IDeleteMissionParams)
{
	const url = 'mission/delete'
	return http.post(url, params)
}

/**
 * Get download url for resources on Aliyun OSS
 */
export function getAliyunOSSDownloadUrl(params: IGetAliyunOSSDownloadURLParams)
{
	const url = `oss/downloadUrl?url=${params.url}&bucket=${params.bucket}&objectName=${params.objectName}&accessToken=${params.accessToken}`;

	return http.get(url);
}

export function postRecoverMission(params)
{
	const url = 'mission/recover'
	return http.post(url, params)
}


/**
 * Gets the product info from mesh server
 *
 * @param productId - id of product we are looking at
 * @param lang - language parameter we are including in headers to get proper localiztion messages
 */
export function getProduct(productId: string, lang: string): Promise<any>
{
	const url = `product?productId=${productId}`;

	return http.get<IProductResponse>(url, {
		headers: {
			'Accept-Language': lang,
		}
	});
}

/**
 * Gets a list of mission for a specific user
 *
 * @param {number} userId - id of user owning missions
 * @param {string} accessToken - access token of the mission
 * @param {number} page - optional, the page of mission returned
 * @param {number} cnt - optional, the maximum number of mission returned
 * @param {string} missionName - optional, search missions by name
 * @param {boolean} deleted - optional, whether to return deleted missions or not
 */
export function getMissions(userId, accessToken, page, cnt, missionName, deleted = false): Promise<any>
{
	const GET_MISSION_BASE_ENDPOINT = "users/{0}/missions?accessToken={1}&order=desc";
	const COUNT_QUERY = "&count={0}";
	const PAGE_QUERY = "&page={0}";
	const DELETED_QUERY = "&trash={0}";
	const NAME_QUERY = "&missionName={0}";

	let url = GET_MISSION_BASE_ENDPOINT.format(userId, accessToken);

	if (page)
	{
		url += PAGE_QUERY.format(page);
	}

	if (cnt)
	{
		url += COUNT_QUERY.format(cnt);
	}

	if (deleted)
	{
		url += DELETED_QUERY.format(deleted.toString());
	}

	if (missionName)
	{
		url += NAME_QUERY.format(missionName);
	}

	return http.get<IMissionListResponse>(url);
}

/**
 * Return list of features of a mission for a specific user
 *
 * @param {number} userId - id of user owning missions
 * @param {number} missionId - id of the mission
 * @param {string} accessToken - access token of the mission
 */
export function getFeatures(userId, missionId, accessToken): Promise<any>
{
	const GET_FEATURES_BASE_ENDPOINT = "users/{0}/missions/{1}/features?accessToken={2}";

	const url = GET_FEATURES_BASE_ENDPOINT.format(userId, missionId, accessToken);

	return http.get<IFeatureListtResponse>(url);
}

export function getDeletedMissions(userId, accessToken, page)
{
	const url = `users/${userId}/missions?accessToken=${accessToken}&count=15&order=incr&page=${page}&trash=true`
	return http.get(url)
}

export function getMissionEvents({ userId, missionId, accessToken, page })
{
	// const url = `users/${userId}/missions/${missionId}/events?accessToken=${accessToken}&count=20&page=${page}&filter=image,video`
	const url = `users/${userId}/missions/${missionId}/events?accessToken=${accessToken}`
	return http.get(url)
}

/**
 * @export getMissionDevices
 * @param {accessToken: String, missionId: String} params
 * @returns Api call
 */
export function getMissionDevices({ accessToken, missionId }): Promise<any>
{
	const url = `mission/devices?accessToken=${accessToken}&missionId=${missionId}`
	return http.get<IMissionDeviceResponse>(url)
}

export function getMissionTorrents({ accessToken, missionId })
{
	const url = `torrents?accessToken=${accessToken}&missionId=${missionId}`
	return http.get(url)
}

/**
 *
 * @export
 * @param {any} params
 * @param {String} params.accessToken - access token for mesh-server.
 * @param {String} params.bucket - name of the bucket in qiniu.
 * @param {String} params.key - will be id for that torrent files.
 * @returns {Object}
 * "data": {
 *          "uploadUrl": "http://upload.qiniu.com/",        // 上传 url
 *          "uploadToken": "GtMGhFn8tHX4Wsb8V0MbQN8JoCCRuWOPUxQSWCeb:WzLepNiD4GicZpvCuhecaROdo9E=:eyJzY29wZSI6Im1lc2gtYXZhdGFyOmFzZGtqbHp4aGNsa2pxd25lbGtqcW5renhjYXNkYXNkIiwiZGVhZGxpbmUiOjE0NzUwMzM2ODN9",
 *          "downloadUrl": "http://oe6xdldcb.bkt.clouddn.com/key"       // 下载 url
 *      }
 */
export function getCDNUploadToken(params)
{
	const url = `cdn/uploadToken?accessToken=${params.accessToken}&bucket=${params.bucket}&key=${params.key}`
	return http.get(url)
}

export function checkCDNfileExist(resourceUrl)
{
	const url = `${resourceUrl}?stat`
	return http.get(url)
}

// TODO: rename this ORZ
export async function postStartAjob(params)
{
	const url = `service/job`;

	return await http.post(url, params)
}

export async function getJobStatus(params)
{
	const url = `service/job/status?accessToken=${params.accessToken}&missionId=${params.missionId}&featureHash=${params.featureHash}&serviceId=${params.serviceId}&eventType=${params.eventType}`
	return await http.get(url)
}

/**
 * Create a service job with in a mesh mission
 *
 * @param {ICreateMeshJobParams} - parameters used to create a mesh service job
 */
export function createMeshJob(params: ICreateMeshJobParams): Promise<any>
{
	const url = "/service/meshJob";

	return http.post<ICreateCloudJobResponse>(url, params);
}

/**
 * Get all service jobs with in a mesh mission
 *
 * @param {IGetMeshJobsParams} - parameters used to create a mesh service job
 */
export function getMeshJobs(params: IGetMeshJobsParams): Promise<any>
{
	const { accessToken, missionId } = params;
	const BASE_URL = "service/meshJobs?accessToken={0}&missionId={1}";

	const url = BASE_URL.format(accessToken, missionId);

	return http.get<IGetMeshJobsParams>(url);
}

/**
 *
 *
 * @export
 * @param {any} params
 * @param {String} params.accessToken - access token for mesh-server.
 * @param {String} params.bucket - name of the bucket in qiniu.
 * @param {String} params.key -- will be id for that torrent files.
 * @returns
 * "data": {
 *          "downloadUrl": "http://oe6xdldcb.bkt.clouddn.com"
 *      }
 */
export function getCDNDownloadURL(params)
{
	const url = `cdn/downloadURL?accessToken=${params.accessToken}&bucket=${params.bucket}&key=${params.key}`
	return http.get(url)
}

export function uploadMissionTorrents(params)
{
	const url = `torrents`
	return http.post(url, params)
}

export function updateTorrentInformation(params)
{
	const url = `torrents/update`
	return http.post(url, params)
}

export function getSubscriptionList(accessToken)
{
	const url = `subscriptions?accessToken=${accessToken}`
	return http.get(url)
}

export function subscribe(userId, params)
{
	const url = `users/${userId}/subscription`
	return http.post(url, params)
}

export function getUserSubscription(userId, accessToken)
{
	const url = `users/${userId}/subscription?accessToken=${accessToken}`
	return http.get(url)
}

export function uploadKml(formData): Promise<any>
{
	const url = `mission/config`
	return http.post(url, formData)
}

/**
 * Gets captured position record for a mission
 *
 * @param {string} accessToken - access token for theuser
 * @param {bigint} missionId - id of mission we are looking at
 */
export async function getCapturePositionRecordForMission(accessToken, missionId): Promise<any>
{
	const BASE_URL = "mission/capture/position?accessToken={0}&missionId={1}";

	const url = BASE_URL.format(accessToken, missionId);

	return await http.get(url);
}

/**
 * Getting OSS AccessToken
 *
 * @param {any} params - params to post to url in order to get oss access token
 */
export async function getOSSAccessToken(params)
{
	const url = "/api/oss/ststoken";

	return await http.post(url, params);
}

/**
 * Add clips to database
 *
 * @param {IAddClipsParams} params
 */
export async function addClips(params: IAddClipsParams)
{
	const url = "/mission/clips/add";

	return await http.post(url, params);
}

/**
 * Delete clips from database
 *
 * @param {any} params
 */
export async function deleteClips(params)
{
	const url = "/mission/clips/delete";

	return await http.post(url, params);
}

/**
 * Returns the geo information by referencing lat/lng from google/gaode map api
 *
 * Related doc:
 * https://developers.google.com/maps/documentation/geocoding/start?csw=1#ReverseGeocoding
 * https://lbs.amap.com/api/webservice/guide/api/georegeo
 *
 * @param lat - lattitude to reference the geo information
 * @param lng - longitude to reference the geo information
 * @param lang - language to be returned
 */
export async function getGeocode(lat: number, lng: number, lang: string)
{
	// Define some necessary constants
	const GAODE_DEV_KEY = "f7c545d3463b78938453242852c9980c";
	const GAODE_STATUS_OK = 200;
	const GOOGLE_STATUS_OK = "OK";

	const googleUrl = `http://maps.googleapis.com/maps/api/geocode/json?latlng=${lat},${lng}&sensor=true&language=${lang}`;
	const gaodeUrl = `https://restapi.amap.com/v3/geocode/regeo?key=${GAODE_DEV_KEY}&location=${lng},${lat}`;

	let response;
	if (lang === "zh-CN" || lang === "zh-TW")
	{
		response = await http.get(gaodeUrl);

		if (response.status === GAODE_STATUS_OK)
		{
			return response.regeocode && response.regeocode.addressComponent ? formatAddress(response.regeocode.addressComponent, lang) : null;
		}
	}
	else
	{
		response = await http.get(googleUrl);

		if (response.status === GOOGLE_STATUS_OK)
		{
			return response.results && response.results.length > 0 ? formatAddress(response.results[0], lang) : null;
		}
	}
}

/**
 * Return a formatted address from a given addressComponent returned by some Map API
 *
 * @param addressComponent - the returned addressComopnent we are looking at
 * @param lang - language to be returned
 */
function formatAddress(addressComponent: any, lang: string)
{
	if (lang === "zh-CN" || lang === "zh-TW")
	{
		return `${addressComponent.country}${addressComponent.province}${addressComponent.city}${addressComponent.district}`;
	}
	else
	{
		return addressComponent.formatted_address.split(",").splice(1).join(",");
	}
}
/**
 * Service related
 */
export function getJobsStatus(params: IGetJobStatusParams): Promise<any>
{
	const url = "/service/getJobsStatus";

	return http.post<IGetJobStatusResponse>(url, params);
}

/**
 * Create an independent cloud job
 *
 * @param {ICreateCLoudJobParams} params - parameters to create an independent cloud job
 */
export function createCloudJob(params: ICreateCloudJobParams): Promise<any>
{
	const url = "/service/cloudJob";
	return http.post<ICreateCloudJobResponse>(url, params)
}

/**
 * Create some independent cloud job
 * @param params {IBulkCreateMeshJobParams} params - parameters to create some independent cloud job
 */
export function blukCreateCloudJob(params: IBulkCreateMeshJobParams): Promise<any>
{
	const url = "/service/meshJobs";
	return http.post<IBulkCreateMeshJobResponse>(url, params)
}

/**
 * Get a list of cloud jobs
 */
export function getCloudJobs(params: IGetCloudJobsParams, useMock?: boolean): Promise<any>
{
	const { accessToken, page, count, order } = params;

	if (!useMock)
	{
		const BASE_URL = "/service/cloudJobs?accessToken={0}&page={1}&count={2}&order={3}";

		const url = BASE_URL.format(accessToken, page, count, order ? order : 'desc');

		return http.get<IGetCloudJobsResponse>(url);
	}
	else
	{
		const successJob = MockServiceJob.mockJob(null, CloudServiceStatus.SUCCESS);
		const uploadingJob = MockServiceJob.mockJob(null, CloudServiceStatus.UPLOADING);
		const pendingJob = MockServiceJob.mockJob(null, CloudServiceStatus.PENDING);
		const failedJob = MockServiceJob.mockJob(null, CloudServiceStatus.FAILED);
		const altizureJob = MockServiceJob.mockJob(ServiceIds.MESH_ALTIZURE, CloudServiceStatus.PENDING);
		const panoramaJob = MockServiceJob.mockJob(ServiceIds.MESH_PANORAMA, CloudServiceStatus.PENDING);

		const result = [successJob, pendingJob, uploadingJob, failedJob, altizureJob, panoramaJob];

		return new Promise((resolve, reject) =>
		{
			resolve({
				code: ResponseCode.SUCCESS,
				message: "",
				data: {
					more: false,
					jobs: result,
				},
			});
		})
	}
}

/**
 * Start a cloud job
 */
export function startCloudJob(params: IStartCloudJobParams): Promise<any>
{
	const url = "/service/startJob";
	return http.post<IStartCloudJobParams>(url, params);
}

/**
 * Add resources to a cloud job
 */
export function addCloudJobResources(params: IAddCloudJobResourcesParams): Promise<any>
{
	const url = "/service/jobResources";

	return http.post<IAddCloudJobResourcesParams>(url, params);
}

/**
 * Remove a cloud job
 *
 * @param {IRemoveJobsParams} params - parameters to remove a cloud job
 */
export function cancelCloudJobs(params: IRemoveJobsParams): Promise<any>
{
	const url = "/service/removeJobs";

	/**
	 * Restart a cloud job
	 *
	 * @param {IRemoveJobsParams} params - parameters to restart a cloud job
	 */
	return http.post<IRemoveJobsResponse>(url, params);
}

/**
 * Restart a list of cloud jobs
 *
 * @param {IRestartJobsParams} params - parameters to restart a list of cloud jobs
 */
export function restartCloudJobs(params: IRestartJobsParams): Promise<any>
{
	const url = "/service/restartJobs";

	return http.post<IRestartJobsParams>(url, params);
}

/**
 * Search jobs and return a list of job objects
 *
 * @param {ISearchJobsParams} params - parameters used to search jobs
 */
export function searchJobs(params: ISearchJobsParams): Promise<any>
{
	const url = "/service/searchJobs";

	return http.post<ISearchJobsParams>(url, params);
}

/**
 * Search a user and return a list of user objects
 *
 * @param {ISearchUserParams} params - parameters used to search a user
 */
export function searchUser(params: ISearchUserParams): Promise<any>
{
	const url = "/user/search";

	return http.post<ISearchUserParams>(url, params);
}

/**
 * Recover a mission
 *
 * @param {IRecoverMissionParams} params - parameters used to recover a mission
 */
export function recoverMission(params: IRecoverMissionParams): Promise<any>
{
	const url = "/mission/recover";

	return http.post<IRecoverMissionParams>(url, params);
}

/**
 * Delete missions
 * 
 * @param {IEmptyTrashMissionParams} params 
 */
export function emptyTrashMission(params: IEmptyTrashMissionParams): Promise<any>
{
	const url = '/mission/emptytrash'

	return http.post<IEmptyTrashMissionParams>(url, params)
}

/**
 * Share a mission with a user
 *
 * @param {IShareMissionParams} params - parameters used to share a mission
 */
export function shareMission(params: IShareMissionParams): Promise<any>
{
	const url = "/mission/share";

	return http.post<IShareMissionParams>(url, params);
}

/**
 * Remove a member from a mission
 *
 * @param {IRemoveMemberParams} params - parameters used to remove a member from a mission
 */
export function removeMember(params: IRemoveMemberParams): Promise<any>
{
	const url = "/mission/removeMember";

	return http.post<IRemoveMemberParams>(url, params);
}

/**
 * Search missions
 *
 * @param params - parameters used to search missions
 */
export function searchMissions(params: ISearchMissionListParams)
{
	const url = 'mission/search'

	return http.post(url, params)
}

/**
 * Get mission info
 * @param params  - parameters used to get mission
 */
export async function missionInfo(params: IMissionInfoParams): Promise<any>
{
	const BASE_URL = "mission/info?accessToken={0}&missionId={1}";

	const url = BASE_URL.format(params.accessToken, params.missionId);

	return http.get(url)
}
