/**
 * Base response interface
 */
interface IResponseBase
{
	/**
	 * Response code designed by backend, refer to backend doc for more information
	 */
	code: ResponseCode;

	/**
	 * Message contained in response, returned by backend
	 */
	message: string;

	/**
	 * Specific data returned from the response, need to be defined by child interfaces
	 */
	data: any;
}

enum ResponseCode
{
	INTERNAL_SERVER_ERROR = 0,
	SUCCESS = 1,
	INVALID_USERNAME = 2,
	ACCOUNT_NOT_EXIST = 3,
	INVALID_PASSWORD = 4,
	INVALID_ACCESS_TOKEN = 5,
	INVALID_PARAMETER = 6,
	DUPLICATED_ACCOUNT = 7,
	INVALID_DATA = 9,
	ARREARAGE_ACCOUNT = 10,
	CANNOT_ACCESS_MISSION = 11,
	DEVICE_COUNT_OVER_LIMIT = 12,
	CAPTCHA_REQUEST_TOO_FREQUENT = 13,
	REQUEST_ERROR = 14,
	UNVERIFIED_PAYMENT = 15,
	INVALID_PHONE_NUM = 16,
	INVALID_EMAIL = 17,
	INVALID_MISSION_NAME = 18,
	INVALID_NEW_PASSWORD = 19,
	INVALID_CDN_APPLY_TIME = 20,
	INVALID_CDN_SIGN = 21,
	DEVICE_BUSY = 22,
	MISSION_NOT_EXIST = 23,

	// Belows are for service
	INVALID_SERVICE_ACCESS_KEY = 81,
	INVALID_SERVICE_SIGNATURE = 82,
	CANNOT_ACCESS_SERVICE = 83,
	SERVICE_NOT_EXIST = 84,

	// Belows are for pricing
	MISSION_TIMES_OVER_LIMIT = 101,
	TRIAL_MISSION_OVER_LIMIT = 102,

	// Belows are for CDN
	CDN_BUCKET_NOT_EXIST = 121,

	// Belows are for user
	USER_NOT_EXIST = 141,
	REFRESH_TOKEN_INVALID = 142,

	// Belows are for developer
	INVALID_DEVELOPER_ACCESS_KEY = 161,
	INVALID_DEVELOPER_SIGNATURE = 162,

	// Belows are for package
	PACKAGE_NOT_EXIST = 181,
	MESH_ENGINE_INCOMPATIBLE = 182,
	PACKAGE_VERSION_NOT_EXIST = 183,

	// Belows are for mission
	UNAUTHORIZED_MISSION_UPDATE = 201,
	UNAUTHORIZED_MISSION_RESTART = 202,
	NO_CAPTURE_EVENTS = 203,
	UNAUTHORIZED_CLIP_ADD = 204,
	UNAUTHORIZED_CLIP_DELETE = 205,

	// Belows are for product
	PRODUCT_NOT_EXIST = 221,
}

export
{
	IResponseBase,
	ResponseCode,
};