import { UserRoleInMission } from './../user/Role';
import { IResponseBase } from "../Response";
import { ILocation } from "../common/Location";

// Refer to documentation here: http://dev.kiwiinc.net/kiwi-team/CoDrone-Server/wikis/api#user-mission-list

/**
 * Interface for response of mission list
 */
interface IMissionListResponse extends IResponseBase
{
	data: IMissionListResponseData;
}

/**
 * Type of data field for the mission list response
 */
interface IMissionListResponseData
{
	/**
	 * Indicates whether we have more `missions` available to be loaded
	 */
	more: boolean;

	/**
	 * The mission list
	 */
	missions: IMissionListItem[];
}

/**
 * Concrete mission list item returned in list
 */
interface IMissionListItem
{
	/**
	 * Id of the mission
	 */
	missionId: number;

	/**
	 * Id of the mission creator (his userId)
	 */
	creatorId: number;

	/**
	 * Name of the mission
	 */
	missionName: string;

	/**
	 * The mesh engine version returned
	 */
	meshEngineVersion: string;

	/**
	 * timestamp for the creation date/time
	 */
	createdAt: number;

	/**
	 * Timestamp for the finish date/time
	 */
	finishedAt: number;

	/**
	 * If true, its a timeline result, else its a resource result
	 */
	hasTimeline: true;

	/**
	 * Member list
	 */
	members: IMissionListMember[];

	/**
	 * Trade icon's url
	 */
	tradeIcon: string;

	/**
	 * Name of the trade
	 */
	tradeName: string;

	/**
	 * Description of the Trade
	 */
	tradeDesc: string;

	/**
	 * Location the mission was executed
	 */
	location: ILocation;
}

interface IMissionListMember
{
	/**
	 * Id of the member
	 */
	userId: number;

	/**
	 * Member's username
	 */
	username: string;

	/**
	 * Member's avatar url
	 */
	avatar: string;

	/**
	 * Member's email
	 */
	email: string;

	/**
	 * Role of the member in mission
	 */
	role: UserRoleInMission;
}

interface IMissionInfoResponse extends IResponseBase
{
	data: IMissionListItem;
}

export
{
	IMissionListResponse,
	IMissionListResponseData,
	IMissionListItem,
	IMissionListMember,
	IMissionInfoResponse,
};
