/**
 * Convert date value to locale string format, and use `.` as delimeter
 * 
 * @param {*} value  - date value to be converted
 */
export const date = function (value)
{
	return new Date(value).toLocaleString().split(" ")[0].replace(/\//g, ".")
}

/**
 * Convert time in `mm:ss` format
 * 
 * @param {*} time - time in minute, to be converted
 */
export const time = function (time)
{
	const minutes = parseInt((time / 60).toString(), 10)
	const seconds = Math.ceil(time % 60)
	return `${minutes}:${seconds < 10 ? '0' + seconds : seconds}`
}

/**
 * Convert time to annotated string indicating remaining time
 * 
 * @param {*} time - time in minute
 */
export const remain = function (time)
{
	const minutes = parseInt((time / 60).toString(), 10)
	if (minutes < 60)
	{
		return `${minutes || 0}mins`
	}
	else
	{
		const hours = Math.ceil(minutes / 60)
		return `${hours}hours${minutes % 60}mins`
	}

}

/**
 * Convert size into corresponding annotated string
 * 
 * @param {*} size - size to be converted
 */
export const size = function (size)
{
	const Kilobyte = 2 << 9 // 1024
	const Megabyte = 2 << 19 // 1024 * 1024
	const Gigabyte = 2 << 29 // 1024 * 1024 * 1024
	if (size < Kilobyte)
	{
		return `${size}B`
	}
	else if (size < Megabyte)
	{
		return `${(size / Kilobyte).toFixed(0)}KB`
	}
	else if (size < Gigabyte)
	{
		return `${(size / Megabyte).toFixed(1)}MB`
	}
	else
	{
		return `${(size / Gigabyte).toFixed(2)}GB`
	}
}
